@@ -48,7 +48,7 @@ class TeacherMaxStepsCallback(BaseCallback):
         Returns:
             bool: If the callback returns False, training is aborted early.
         """
-        total_steps = self.training_env.get_attr(attr_name="time_steps")[0]  # type: ignore
+        total_steps = self.training_env.get_attr(attr_name="opt")[0].time_steps  # type: ignore
         if total_steps >= self.max_steps:
             return False
         return True
@@ -111,28 +111,29 @@ class TeacherLogCallback(BaseCallback):
             # get session_statistics
             env = self.training_env
             if isinstance(self.training_env, VecEnv):
-                session = DataFrame()
+                sessions = DataFrame()
 
                 for env in self.training_env.envs:  # type: ignore
-                    if len(env.session_statistics) != 0:
-                        session = concat(
-                            [session, DataFrame.from_records(env.session_statistics)]
+                    if len(env.opt.session_statistics) != 0:
+                        session_stats = DataFrame.from_records(
+                            env.opt.session_statistics
                         )
+                        sessions = concat([sessions, session_stats])
 
                         # new_session = session[self.last_len_statistics:]
                         # new_avg_reward = np.mean(new_S["teacher_reward"].values)
                         if self.logpath:
-                            save_log(session, self.verbose, self.logpath)
+                            save_log(sessions, self.verbose, self.logpath)
             else:
-                session = env.session_statistics
+                sessions = env.opt.session_statistics
                 # new_session = session[self.last_len_statistics :]
                 # new_avg_reward = np.mean(new_S["teacher_reward"].values)
                 assert (
                     self.logpath
                 ), "You have to provide a path to save the session logs"
-                save_log(session, self.logpath, self.verbose)
+                save_log(sessions, self.verbose, self.logpath)
 
-            self.last_len_statistics = len(session)
+            self.last_len_statistics = len(sessions)
         return True
 
 
@@ -142,7 +143,7 @@ class TeacherSaveModelCallback(BaseCallback):
     def __init__(
         self,
         train_env: gym.Env,
-        save_path: Optional[str] = None,
+        save_path: str,
         save_freq: int = 1,
         verbose: int = 0,
     ):
@@ -157,10 +158,13 @@ class TeacherSaveModelCallback(BaseCallback):
         This method will be called by the model after each call to `env.step()`.
         :return: (bool) If the callback returns False, training is aborted early.
         """
+        assert self.model, "Model must be loaded first"
         if self.save_freq > 0 and self.n_calls % self.save_freq == 0:
             if isinstance(self.training_env, VecEnv):
                 for env in self.training_env.envs:  # type: ignore
-                    model_save_path = os.path.join(self.save_path, f"{env.time_steps}")
+                    model_save_path = os.path.join(
+                        self.save_path, f"{env.opt.time_steps}"
+                    )
                     self.model.save(path=model_save_path)
         return True
 
